<?php
/**
 * dietbox functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package dietbox
 */


if (!function_exists('dietbox_setup')) :
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function dietbox_setup()
    {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on dietbox, use a find and replace
         * to change 'dietbox' to the name of your theme in all the template files.
         */
        load_theme_textdomain('dietbox', get_template_directory() . '/languages');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'menu-1' => esc_html__('Primary', 'dietbox'),
            'side-nav' => esc_html__('SideNav', 'dietbox'),
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('dietbox_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));
    }
endif;
add_action('after_setup_theme', 'dietbox_setup');


//Custom Search Box

function searchbox()
{
    '<form role="search" method="get" id="searchform" action="http://www.test.dev/">
        <div>
    
            <label for="s">Search for:</label>
    
            <input type="search" placeholder="Search" value="" name="s" id="s" /><i class="fa fa-search"></i>
    
            <input type="hidden" value="1" name="sentence" />
    
            <input type="hidden" value="product" name="post_type" />
    
            <input type="hidden" value="product_cat" name="magazines,books" />
    
            <input type="submit" id="searchsubmit" value="Search" />
    
        </div>

    </form>';
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function dietbox_content_width()
{
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters('dietbox_content_width', 640);
}

add_action('after_setup_theme', 'dietbox_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function dietbox_widgets_init()
{
    register_sidebar(array(
        'name' => esc_html__('Blog Detail Sidebar', 'dietbox'),
        'id' => 'blog-detail-sidebar',
        'description' => esc_html__('Add widgets here.', 'dietbox'),
        'before_widget' => '<div id="%1$s" class="wow fadeInDown widget %2$s"  data-wow-duration="500ms" data-wow-delay="900ms">',
        'after_widget' => '</div>',
        'before_title' => '<h4 class="widget-title">',
        'after_title' => '</h4>',
    ));
}

add_action('widgets_init', 'dietbox_widgets_init');

/**
 * Enqueue scripts and styles.
 */

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
//require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
//require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
//if (defined('JETPACK__VERSION')) {
//    require get_template_directory() . '/inc/jetpack.php';
//}

// Load custom DB error template, if present.
require get_template_directory() . '/inc/thumbs.php';

function misha_my_load_more_scripts()
{

    global $wp_query;

    // In most cases it is already included on the page and this line can be removed
    wp_enqueue_script('jquery');

    // register our main script but do not enqueue it yet
    wp_register_script('my_loadmore', get_stylesheet_directory_uri() . '/assets/js/app.js', array('jquery'));

    // now the most interesting part
    // we have to pass parameters to myloadmore.js script but we can get the parameters values only in PHP
    // you can define variables directly in your HTML but I decided that the most proper way is wp_localize_script()
    wp_localize_script('my_loadmore', 'misha_loadmore_params', array(
        'ajaxurl' => site_url() . '/wp-admin/admin-ajax.php', // WordPress AJAX
        'posts' => json_encode($wp_query->query_vars), // everything about your loop is here
        'current_page' => get_query_var('paged') ? get_query_var('paged') : 1,
        'max_page' => $wp_query->max_num_pages
    ));

    wp_enqueue_script('my_loadmore');
}

add_action('wp_enqueue_scripts', 'misha_my_load_more_scripts');

function misha_loadmore_ajax_handler()
{
    wp_reset_query();

    // prepare our arguments for the query
    $args = json_decode(stripslashes($_POST['query']), true);
    $args['post_type'] = 'post';
    $args['posts_per_page'] = 3;
    $args['paged'] = $_POST['page'] + 1; // we need next page to be loaded
    $args['post_status'] = 'publish';


    // it is always better to use WP_Query but not here
    query_posts($args);

    if (have_posts()) :

        while (have_posts()):
            the_post(); ?>
            <div class="col-md-4">
                <div class="blog_slide static wow slideInLeft">
                    <div class="blog_img">
                        <?php

                        if (has_post_thumbnail()):
                            $image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'blog-thumb'); ?>
                            <img src="<?= $image[0]; ?>" alt="blog_img">
                        <?php

                        else:
                            $image = get_stylesheet_directory_uri() . '/assets/images/gym-fitness-assets/images/gym_blog_1.jpg'; ?>
                            <img src="<?= $image; ?>" alt="blog_img">
                        <?php
                        endif; ?>
                    </div>

                </div>
                <a href="<?= get_the_permalink(); ?>" class="anchor_style_default">

                    <h3 class="small_heading_navy raleway center_on_mobile font_400"><?= get_the_title() ?></h3>

                </a>

                <p class="default_text default_text_light open_sans center_on_mobile"><?= get_the_date() ?></p>
                <p class="default_text open_sans center_on_mobile">

                    <?= get_the_excerpt(); ?>

                </p>

            </div>


        <?php

        endwhile;
    endif;
    wp_die();

}


add_action('wp_ajax_loadmore', 'misha_loadmore_ajax_handler'); // wp_ajax_{action}
add_action('wp_ajax_nopriv_loadmore', 'misha_loadmore_ajax_handler'); // wp_ajax_nopriv_{action}

/**
 * Generate custom search form
 *
 * @param string $form Form HTML.
 * @return string Modified form HTML.
 */
function wpdocs_my_search_form($form)
{

    $form = '
<div class="widget search_box">
    <form role="search" method="get" id="searchform" class="searchform" action="' . home_url('/') . '">
        <input type="text" value="' . get_search_query() . '" name="s" id="s"/>
        <i class="fa fa-search"></i>
</div>
</form>';

    return $form;
}

add_filter('get_search_form', 'wpdocs_my_search_form');

// Load custom DB error template, if present.
include('inc/dietbox-widget.php');


function somename_customize_register($wp_customize)
{
    $wp_customize->get_setting('image_control_one')->transport = 'postMessage';
    // Add and manipulate theme images to be used.
    $wp_customize->add_section('imageoner', array(
        "title" => 'Home Page Images',
        "priority" => 28,
        "description" => __('Upload images to display on the homepage.', 'theme-slug')
    ));
    $wp_customize->add_setting('image_control_one', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'image_control_one', array(
            'label' => __('Featured Home Page Image One', 'theme-slug'),
            'section' => 'imageoner',
            'settings' => 'image_control_one',
        ))
    );

    $wp_customize->add_section('footer-setting', array(
        "title" => 'Footer & Social Media Settings',
        "priority" => 28,
        "description" => __('Copyright text and social media icons ', 'theme-slug')
    ));

    $wp_customize->add_setting('footer', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));


    $wp_customize->add_setting('copyright-text', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control('copyright', array(
        'type' => 'textarea',
        'section' => 'footer-setting', // Add a default or your own section
        'label' => __('Copyright © text'),
        'description' => __('Add Copyright text here'),
        'settings' => 'copyright-text',
        'input_attrs' => array(
            'placeholder' => __('Theme: dietbox by Team Dietbox.'),
        ),
    ));
    $wp_customize->add_setting('social-media-facebook', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control('facebook', array(
        'type' => 'url',
        'section' => 'footer-setting', // Add a default or your own section
        'label' => __('Facebook'),
        'description' => __('Add Facebook url here'),
        'settings' => 'social-media-facebook',
        'input_attrs' => array(
            'placeholder' => __('http://www.facebook.com'),
        ),
    ));
    $wp_customize->add_setting('social-media-twitter', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control('twitter', array(
        'type' => 'url',
        'section' => 'footer-setting', // Add a default or your own section
        'label' => __('Twitter'),
        'description' => __('Add Twitter url here'),
        'settings' => 'social-media-twitter',
        'input_attrs' => array(
            'placeholder' => __('http://www.twiiter.com'),
        ),
    ));
    $wp_customize->add_setting('social-media-isntagram', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control('instagram', array(
        'type' => 'url',
        'section' => 'footer-setting', // Add a default or your own section
        'label' => __('Instagram'),
        'description' => __('Add Insta url here'),
        'settings' => 'social-media-isntagram',
        'input_attrs' => array(
            'placeholder' => __('http://www.isntagram.com'),
        ),
    ));
    $wp_customize->add_setting('social-media-linkedin', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control('linkedin', array(
        'type' => 'url',
        'section' => 'footer-setting', // Add a default or your own section
        'label' => __('Linkedin'),
        'description' => __('Add Linkedin url here'),
        'settings' => 'social-media-linkedin',
        'input_attrs' => array(
            'placeholder' => __('http://www.isntagram.com'),
        ),
    ));
    $wp_customize->add_setting('social-media-pinterest', array(
        'default' => '',
        'type' => 'theme_mod',
        'capability' => 'edit_theme_options',
    ));
    $wp_customize->add_control('pinterest', array(
        'type' => 'url',
        'section' => 'footer-setting', // Add a default or your own section
        'label' => __('Pinterest'),
        'description' => __('Add Pinterest url here'),
        'settings' => 'social-media-pinterest',
        'input_attrs' => array(
            'placeholder' => __('http://www.pinterest.com'),
        ),
    ));

}

add_action('customize_register', 'somename_customize_register');


/**
 * Comment form hidden fields
 */
function comment_form_hidden_fields()
{
    comment_id_fields();
    if (current_user_can('unfiltered_html')) {
        wp_nonce_field('unfiltered-html-comment_' . get_the_ID(), '_wp_unfiltered_html_comment', false);
    }
}


/**
 * Dietbox contact form function
 */
function javascript_variables()
{ ?>
    <script type="text/javascript">
        var ajax_url = '<?php echo admin_url("admin-ajax.php"); ?>';
        var ajax_nonce = '<?php echo wp_create_nonce("secure_nonce_name"); ?>';
    </script><?php
}

add_action('wp_head', 'javascript_variables');

add_action('wp_ajax_contact_form', 'contact_form');
add_action('wp_ajax_nopriv_contact_form', 'contact_form');
function contact_form()
{

    try {

// This is a secure process to validate if this request comes from a valid source.
        //check_ajax_referer('secure-nonce-name', 'security');
        /**
         * First we make some validations,
         * I think you are able to put better validations and sanitizations. =)
         */
        if (empty($_POST["name"])) {
            throw New Exception('Insert your name please');
        }

        if (!filter_var($_POST["email"], FILTER_VALIDATE_EMAIL)) {
            throw New Exception('Insert your email please');
        }

        if (empty($_POST["message"])) {
            throw New Exception('Insert your comment please');
        }

        $data = [
            "name" => $_POST["name"],
            "email" => $_POST["email"],
            "phone" => $_POST["phone"],
            "quote" => $_POST["message"],
            "type" => "BLOG"
        ];

        $response = Requests::post( DIETBOX_SUBSCRIPTION_URL,   array(
            'content-type' => 'application/json'
        ), json_encode($data) );

        echo    $response->body;
        wp_die();
    } catch (Exception $e) {
        echo $e->getMessage();
        wp_die();
    }

//    // This is the email where you want to send the comments.
//    $to = 'ourcompanysemail@example.com';
//
//    // Your message subject.
//    $subject = 'Now message from a client!';
//
//    $body = 'From: ' . $_POST['name'] . '\n';
//    $body .= 'Email: ' . $_POST['name'] . '\n';
//    $body .= 'Message: ' . $_POST['comment'] . '\n';
//
//    // This are the message headers.
//    // You can learn more about them here: https://developer.wordpress.org/reference/functions/wp_mail/
//    $headers = array('Content-Type: text/html; charset=UTF-8');
//
//    wp_mail($to, $subject, $body, $headers);
//
//    echo 'Done!';
//    wp_die();
}



