<?php

/**
 * Dietbox Custom widget class
 *
 */
class WP_Widget_My_Custom_Recent_Posts extends WP_Widget_Recent_Posts
{

    function __construct()
    {
        $widget_ops = array('classname' => 'widget_my_custom_recent_entries', 'description' => __("The most recent posts on your site"));
        $this->WP_Widget('my-custom-recent-posts', __('My Custom Recent Posts'), $widget_ops);
        $this->alt_option_name = 'widget_my_custom_recent_entries';

        add_action('save_post', array(&$this, 'flush_widget_cache'));
        add_action('deleted_post', array(&$this, 'flush_widget_cache'));
        add_action('switch_theme', array(&$this, 'flush_widget_cache'));
    }

    function widget($args, $instance)
    {
        $cache = wp_cache_get('widget_my_custom_recent_posts', 'widget');

        if (!is_array($cache))
            $cache = array();

        if (isset($cache[$args['widget_id']])) {
            echo $cache[$args['widget_id']];
            return;
        }

        ob_start();
        extract($args);

        $title = apply_filters('widget_title', empty($instance['title']) ? __('My Custom Recent Posts') : $instance['title'], $instance, $this->id_base);
        $class = !empty($instance['class']) ? $instance['class'] : 'widget-class';
        if (!$number = (int)$instance['number'])
            $number = 10;
        else if ($number < 1)
            $number = 1;
        else if ($number > 15)
            $number = 15;

        $r = new WP_Query(array('showposts' => $number, 'nopaging' => 0, 'post_status' => 'publish', 'ignore_sticky_posts' => true, 'post_type' => array('post')));


        echo '<div class="widget wow fadeInDown" data-wow-duration="500ms" data-wow-delay="900ms">';

        if ($r->have_posts()) :
            ?>
            <?php echo $before_widget; ?>
            <?php if ($title) echo $before_title . $title . $after_title; ?>
            <ul class="<?= esc_attr($class); ?>">
                <?php while ($r->have_posts()) : $r->the_post(); ?>
                    <li><a href="<?php get_permalink(); ?>"
                           title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if (get_the_title()) the_title(); else the_ID(); ?>
                            <span class="date"><?=   get_the_date();   ?></span>
                        </a>
                    </li>
                <?php endwhile; ?>
            </ul>
            <?php echo $after_widget; ?>
            <?php
            // Reset the global $the_post as this query will have stomped on it
            wp_reset_postdata();

        endif;
        echo '</div>';

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('widget_my_custom_recent_posts', $cache, 'widget');
//        exit;

    }

    function update($new_instance, $old_instance)
    {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['class'] = strip_tags($new_instance['class']);
        $instance['number'] = (int)$new_instance['number'];
        $this->flush_widget_cache();

        $alloptions = wp_cache_get('alloptions', 'options');
        if (isset($alloptions['widget_my_custom_recent_entries']))
            delete_option('widget_my_custom_recent_entries');

        return $instance;
    }

    function flush_widget_cache()
    {
        wp_cache_delete('widget_my_custom_recent_posts', 'widget');
    }

    function form($instance)
    {
        $title = isset($instance['title']) ? esc_attr($instance['title']) : '';
        $class = isset($instance['class']) ? esc_attr($instance['class']) : '';
        if (!isset($instance['number']) || !$number = (int)$instance['number'])
            $number = 5;
        ?>
        <p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>"
                   name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>"/></p>

        <p><label for="<?php echo $this->get_field_id('class'); ?>"><?php _e('Enter class name:'); ?></label>
            <input id="<?php echo $this->get_field_id('class'); ?>" name="<?php echo $this->get_field_name('class'); ?>"
                   type="text" value="<?php echo $class; ?>" size="3"/></p>

        <p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:'); ?></label>
            <input id="<?php echo $this->get_field_id('number'); ?>"
                   name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>"
                   size="3"/></p>
        <?php
    }
}
function my_recent_widget_registration() {
    unregister_widget('WP_Widget_Recent_Posts');
    register_widget('WP_Widget_My_Custom_Recent_Posts');
}
add_action('widgets_init', 'my_recent_widget_registration');

